import { world, ItemStack, GameMode, EquipmentSlot } from '@minecraft/server';
// This array defines the weapon items that will lose durability.
const weaponTypeIds = [
    "tcc_knives:wooden_knife",
    "tcc_knives:stone_knife",
    "tcc_knives:iron_knife",
    "tcc_knives:golden_knife",
    "tcc_knives:diamond_knife",
    "tcc_knives:netherite_knife"
];
world.afterEvents.playerBreakBlock.subscribe((event)=>{
    const { player, itemStackBeforeBreak: itemUsed } = event;
    if (!itemUsed || player.matches({
        gameMode: GameMode.creative
    })) return;
    if (weaponTypeIds.includes(itemUsed.typeId)) {
        const playerEquippableComp = player.getComponent("equippable");
        if (!playerEquippableComp) return;
        const itemEnchantmentComp = itemUsed.getComponent("minecraft:enchantable");
        const unbreakingLevel = itemEnchantmentComp?.getEnchantment("unbreaking")?.level ?? 0;
        const breakChance = 100 / (unbreakingLevel + 1);
        const randomizeChance = Math.random() * 100;
        if (breakChance < randomizeChance) return;
        const itemUsedDurabilityComp = itemUsed.getComponent("durability");
        if (!itemUsedDurabilityComp) return;
        const durabilityModifier = 2;
        if (itemUsedDurabilityComp.damage + durabilityModifier < itemUsedDurabilityComp.maxDurability) {
            itemUsedDurabilityComp.damage += durabilityModifier;
            playerEquippableComp.setEquipment(EquipmentSlot.Mainhand, itemUsed);
        } else {
            player.playSound('random.break', {
                pitch: 1,
                location: player.location,
                volume: 1
            });
            playerEquippableComp.setEquipment(EquipmentSlot.Mainhand, new ItemStack('minecraft:air', 1));
        }
    }
});
